@@ -45,9 +45,7 @@ def extend_docstrings() -> None:
             continue
         function_arguments = inspect.signature(definition).parameters
         if len(function_arguments):
-            raise ValueError(
-                f"Local function {name} should not have a signature"
-            )
+            raise ValueError(f"Local function {name} should not have a signature")
         definition()
 
 
@@ -78,10 +76,10 @@ def extend_BoostMatrix() -> None:
     _append_to_docstring(
         BoostMatrix,
         """
-    In `TensorWaves <https://tensorwaves.rtfd.io>`_, this class is expressed in
-    a computational backend and it should operate on four-momentum arrays of
-    rank-2. As such, this boost matrix becomes a **rank-3** matrix. When using
-    `NumPy <https://numpy.org>`_ as backend, the computation looks as follows:
+    In `TensorWaves <https://tensorwaves.rtfd.io>`_, this class is expressed in a
+    computational backend and it should operate on four-momentum arrays of rank-2. As
+    such, this boost matrix becomes a **rank-3** matrix. When using `NumPy
+    <https://numpy.org>`_ as backend, the computation looks as follows:
     """,
     )
     _append_code_rendering(
@@ -108,10 +106,10 @@ def extend_BoostZMatrix() -> None:
     _append_to_docstring(
         BoostZMatrix,
         """
-    In `TensorWaves <https://tensorwaves.rtfd.io>`_, this class is expressed in
-    a computational backend and it should operate on four-momentum arrays of
-    rank-2. As such, this boost matrix becomes a **rank-3** matrix. When using
-    `NumPy <https://numpy.org>`_ as backend, the computation looks as follows:
+    In `TensorWaves <https://tensorwaves.rtfd.io>`_, this class is expressed in a
+    computational backend and it should operate on four-momentum arrays of rank-2. As
+    such, this boost matrix becomes a **rank-3** matrix. When using `NumPy
+    <https://numpy.org>`_ as backend, the computation looks as follows:
     """,
     )
     b = sp.Symbol("b")
@@ -127,12 +125,11 @@ def extend_BoostZMatrix() -> None:
         BoostZMatrix,
         """
     Note that this code was generated with :func:`sympy.lambdify
-    <sympy.utilities.lambdify.lambdify>` with :code:`cse=True`. The repetition
-    of :func:`numpy.ones` is still bothersome, but these sub-nodes is also
-    extracted by :func:`sympy.cse <sympy.simplify.cse_main.cse>` if the
-    expression is nested further down in an :doc:`expression tree
-    <sympy:tutorial/manipulation>`, for instance when boosting a
-    `.FourMomentumSymbol` :math:`p` in the :math:`z`-direction:
+    <sympy.utilities.lambdify.lambdify>` with :code:`cse=True`. The repetition of
+    :func:`numpy.ones` is still bothersome, but these sub-nodes is also extracted by
+    :func:`sympy.cse <sympy.simplify.cse_main.cse>` if the expression is nested further
+    down in an :doc:`expression tree <sympy:tutorials/intro-tutorial/manipulation>`, for
+    instance when boosting a `.FourMomentumSymbol` :math:`p` in the :math:`z`-direction:
     """,
     )
     p, beta, phi, theta = sp.symbols("p beta phi theta")
@@ -241,20 +238,15 @@ def extend_EnergyDependentWidth() -> None:
     _append_to_docstring(
         EnergyDependentWidth,
         R"""
-    where :math:`B_L^2` is defined by :eq:`BlattWeisskopfSquared`, :math:`q` is
-    defined by :eq:`BreakupMomentumSquared`, and :math:`\rho` is (by default)
-    defined by :eq:`PhaseSpaceFactor`.
+    where :math:`B_L^2` is defined by :eq:`BlattWeisskopfSquared`, :math:`q` is defined
+    by :eq:`BreakupMomentumSquared`, and :math:`\rho` is (by default) defined by
+    :eq:`PhaseSpaceFactor`.
     """,
     )
 
 
 def extend_Energy_and_FourMomentumXYZ() -> None:
-    from ampform.kinematics import (
-        Energy,
-        FourMomentumX,
-        FourMomentumY,
-        FourMomentumZ,
-    )
+    from ampform.kinematics import Energy, FourMomentumX, FourMomentumY, FourMomentumZ
 
     def _extend(component_class: Type[sp.Expr]) -> None:
         _append_to_docstring(component_class, "\n\n")
@@ -282,9 +274,7 @@ def extend_formulate_form_factor() -> None:
     from ampform.dynamics import formulate_form_factor
 
     s, m_a, m_b, L, d = sp.symbols("s m_a m_b L d")
-    form_factor = formulate_form_factor(
-        s, m_a, m_b, angular_momentum=L, meson_radius=d
-    )
+    form_factor = formulate_form_factor(s, m_a, m_b, angular_momentum=L, meson_radius=d)
     _append_to_docstring(
         formulate_form_factor,
         f"""
@@ -415,8 +405,8 @@ def extend_RotationYMatrix() -> None:
     _append_to_docstring(
         RotationYMatrix,
         f"""\n
-    The matrix for a rotation over angle :math:`\\alpha` around the
-    :math:`y`-axis operating on `FourMomentumSymbol` looks like:
+    The matrix for a rotation over angle :math:`\\alpha` around the :math:`y`-axis
+    operating on `FourMomentumSymbol` looks like:
 
     .. math:: {sp.latex(expr)} = {sp.latex(expr.as_explicit())}
         :label: RotationYMatrix
@@ -434,8 +424,8 @@ def extend_RotationZMatrix() -> None:
     _append_to_docstring(
         RotationZMatrix,
         f"""\n
-    The matrix for a rotation over angle :math:`\\alpha` around the
-    :math:`z`-axis operating on `FourMomentumSymbol` looks like:
+    The matrix for a rotation over angle :math:`\\alpha` around the :math:`z`-axis
+    operating on `FourMomentumSymbol` looks like:
 
     .. math:: {sp.latex(expr)} = {sp.latex(expr.as_explicit())}
         :label: RotationZMatrix
@@ -444,10 +434,10 @@ def extend_RotationZMatrix() -> None:
     _append_to_docstring(
         RotationZMatrix,
         """
-    In `TensorWaves <https://tensorwaves.rtfd.io>`_, this class is expressed in
-    a computational backend and it should operate on four-momentum arrays of
-    rank-2. As such, this boost matrix becomes a **rank-3** matrix. When using
-    `NumPy <https://numpy.org>`_ as backend, the computation looks as follows:
+    In `TensorWaves <https://tensorwaves.rtfd.io>`_, this class is expressed in a
+    computational backend and it should operate on four-momentum arrays of rank-2. As
+    such, this boost matrix becomes a **rank-3** matrix. When using `NumPy
+    <https://numpy.org>`_ as backend, the computation looks as follows:
     """,
     )
     a = sp.Symbol("a")
@@ -560,13 +550,13 @@ def extend_get_boost_chain_suffix() -> None:
     )
     graphviz0 = _graphviz_to_image(
         dot0,
-        indent=6,
+        indent=8,
         caption=":code:`topologies[0]`",
         label="one-to-five-topology-0",
     )
     graphviz1 = _graphviz_to_image(
         dot1,
-        indent=6,
+        indent=8,
         caption=":code:`topologies[1]`",
         label="one-to-five-topology-1",
     )
@@ -574,12 +564,14 @@ def extend_get_boost_chain_suffix() -> None:
         get_boost_chain_suffix,
         f"""
 
-    .. panels::
-      :body: text-center
-      {graphviz0}
+    .. grid:: 1 2 2 2
+      :gutter: 2
 
-      ---
-      {graphviz1}
+      .. grid-item-card::
+        {graphviz0}
+
+      .. grid-item-card::
+        {graphviz1}
     """,
     )
 
@@ -615,8 +607,7 @@ def extend_relativistic_breit_wigner_with_ff() -> None:
     _append_to_docstring(
         relativistic_breit_wigner_with_ff,
         Rf"""
-    The general form of a relativistic Breit-Wigner with Blatt-Weisskopf form
-    factor is:
+    The general form of a relativistic Breit-Wigner with Blatt-Weisskopf form factor is:
 
     .. math:: {sp.latex(rel_bw_with_ff)}
         :label: relativistic_breit_wigner_with_ff
@@ -646,10 +637,7 @@ def _append_code_rendering(
     numpy_code = textwrap.dedent(numpy_code)
     numpy_code = textwrap.indent(numpy_code, prefix=8 * " ").strip()
     options = ""
-    if (
-        max(__get_text_width(import_statements), __get_text_width(numpy_code))
-        > 90
-    ):
+    if max(__get_text_width(import_statements), __get_text_width(numpy_code)) > 90:
         options += ":class: full-width\n"
     appended_text = f"""\n
     .. code-block:: python
@@ -699,9 +687,7 @@ def _create_latex_doit_definition(expr: sp.Expr, deep: bool = False) -> str:
     return textwrap.indent(latex, prefix=8 * " ")
 
 
-def _append_to_docstring(
-    class_type: Union[Callable, Type], appended_text: str
-) -> None:
+def _append_to_docstring(class_type: Union[Callable, Type], appended_text: str) -> None:
     assert class_type.__doc__ is not None
     class_type.__doc__ += appended_text
 
